﻿using System.Drawing;
using Infragistics.Win;
using Infragistics.Win.UltraWinTree;

namespace UltraTreeWithPIcturesAndColorText
{
    public class DrawFilter : IUIElementDrawFilter
    {

        bool IUIElementDrawFilter.DrawElement(DrawPhase drawPhase, ref UIElementDrawParams drawParams)
        {
            TextUIElement currentTextUI = drawParams.Element as TextUIElement;
            Rectangle currentTextRectangle = currentTextUI.Rect;
            Font textFont = currentTextUI.Control.Font;

            string currentText = currentTextUI.Text;
            int dashPosition = currentText.IndexOf('-');
            string blackText = currentText.Substring(0, dashPosition);
            string greyText = currentText.Substring(dashPosition);

            SizeF blackStringSize = new SizeF();
            blackStringSize = drawParams.Graphics.MeasureString(blackText, textFont);

            Point blackTextStartPoint = currentTextRectangle.Location;
            PointF greyTextStartPoint = new PointF(currentTextRectangle.Left + blackStringSize.Width, currentTextRectangle.Top);

            drawParams.Graphics.DrawString(blackText, textFont, Brushes.Black, blackTextStartPoint);
            drawParams.Graphics.DrawString(greyText, textFont, Brushes.Gray, greyTextStartPoint);

            return true;
        }

        DrawPhase IUIElementDrawFilter.GetPhasesToFilter(ref UIElementDrawParams drawParams)
        {
            if (drawParams.Element is TextUIElement)
            {
                TextUIElement currentText = drawParams.Element as TextUIElement;
                var nodeElement = currentText.GetAncestor(typeof(TreeNodeUIElement)) as TreeNodeUIElement;

                if (nodeElement != null && nodeElement.Node.Level == 0)
                {
                    return DrawPhase.BeforeDrawForeground;
                }
            }

            return DrawPhase.None;
        }
    }
}